# This is the list of people (as distinct from [AUTHORS](AUTHORS)) who have contributed code to Pyzotero.

| **Commits** | **Contributor**<br/> |
| --- |--- |
| 13 | [TruePath](https://github.com/urschrei/pyzotero/commits?author=TruePath) |
| 5 | [patrickfournier](https://github.com/urschrei/pyzotero/commits?author=patrickfournier) |
| 3 | [davidlesieur](https://github.com/urschrei/pyzotero/commits?author=davidlesieur) |
| 2 | [ptgolden](https://github.com/urschrei/pyzotero/commits?author=ptgolden) |
| 2 | [bemuzie](https://github.com/urschrei/pyzotero/commits?author=bemuzie) |
| 2 | [skybristol](https://github.com/urschrei/pyzotero/commits?author=skybristol) |
| 1 | [akx](https://github.com/urschrei/pyzotero/commits?author=akx) |
| 1 | [alee](https://github.com/urschrei/pyzotero/commits?author=alee) |
| 1 | [avram](https://github.com/urschrei/pyzotero/commits?author=avram) |
| 1 | [christianbrodbeck](https://github.com/urschrei/pyzotero/commits?author=christianbrodbeck) |
| 1 | [egh](https://github.com/urschrei/pyzotero/commits?author=egh) |
| 1 | [fmagin](https://github.com/urschrei/pyzotero/commits?author=fmagin) |
| 1 | [porduna](https://github.com/urschrei/pyzotero/commits?author=porduna) |
| 1 | [stakats](https://github.com/urschrei/pyzotero/commits?author=stakats) |
| 1 | [epistemery](https://github.com/urschrei/pyzotero/commits?author=epistemery) |
| 1 | [jghauser](https://github.com/urschrei/pyzotero/commits?author=jghauser) |
